﻿/*
    Program ukazující serializaci pomocí třídy XmlSerializer.
*/

using System;
using System.Collections.Generic;
using System.Xml.Serialization;
using System.IO;

namespace XMLSerialization
{
    public class User
    {
        //[XmlAttribute("FirstName")]
        public string FirstName { get; set; }
        //[XmlAttribute("LastName")]
        public string LastName { get; set; }
        //[XmlAttribute("Born")]
        public DateTime Born { get; set; }

        public override string ToString()
        {
            return FirstName + " " + LastName + ", narozen: " +
                   Born.Day + ". " + Born.Month + ". " + Born.Year;
        }
    }

    class Program
    {
        private static List<User> users;

        public static void Serialize()
        {
            XmlSerializer xmlSerializer =
                new XmlSerializer(typeof(List<User>));

            using (StreamWriter sw = new StreamWriter("Users.xml"))
            {
                xmlSerializer.Serialize(sw, users);
            }
        }

        public static void Deserialize()
        {
            XmlSerializer xmlSerializer =
                new XmlSerializer(users.GetType());

            using (StreamReader sr = new StreamReader("Users.xml"))
            {
                users = (List<User>)xmlSerializer.Deserialize(sr);
            }
        }

        public static void WriteUsers()
        {
            Console.WriteLine("Seznam uživatelů:");
            Console.WriteLine("-----------------");
            Console.WriteLine();

            foreach (User u in users)
                Console.WriteLine(u.ToString());

            Console.WriteLine();
        }

        static void Main(string[] args)
        {
            users = new List<User>
            {
               new User { FirstName = "Jan", LastName = "Novak",
                          Born = new DateTime (1990, 10, 1)
                        },
               new User { FirstName = "Pavel", LastName = "Svoboda",
                          Born = new DateTime (1995, 8, 2)
                        },
               new User { FirstName = "Michal", LastName = "Blazek",
                          Born = new DateTime (1984, 11, 5)
                        }
            };

            WriteUsers();
            Serialize();

            users.Clear();
            WriteUsers();

            Deserialize();
            WriteUsers();
        }
    }
}

